==> apache-cxf-3.4.10.tar.gz: apache-cxf-3.4.10/samples/ws_transaction/ws_second/src/main/java/sample/ws/WebServiceConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package sample.ws;

import javax.xml.ws.Endpoint;

import com.arjuna.webservices11.wsat.sei.ParticipantPortTypeImpl;
import org.apache.cxf.Bus;
import org.apache.cxf.jaxws.EndpointImpl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import sample.ws.service.SecondServiceATImpl;

@Configuration
public class WebServiceConfig {

    @Autowired
    private Bus bus;

    @Autowired
    private SecondServiceATImpl impl;

    @Bean
    public Endpoint endpoint() {
        EndpointImpl endpoint = new EndpointImpl(bus, impl);
        endpoint.publish("/Service/SecondServiceAT");
        return endpoint;
    }

    @Bean
    public Endpoint participant() {
        EndpointImpl endpoint = new EndpointImpl(bus, new ParticipantPortTypeImpl());
        endpoint.publish("/ws-t11-participant/ParticipantService");
        return endpoint;
    }
}

==> apache-cxf-4.0.6.tar.gz: apache-cxf-4.0.6/samples/ws_transaction/ws_second/src/main/java/sample/ws/WebServiceConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package sample.ws;

import jakarta.xml.ws.Endpoint;

import com.arjuna.webservices11.wsat.sei.ParticipantPortTypeImpl;
import org.apache.cxf.Bus;
import org.apache.cxf.jaxws.EndpointImpl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import sample.ws.service.SecondServiceATImpl;

@Configuration
public class WebServiceConfig {

    @Autowired
    private Bus bus;

    @Autowired
    private SecondServiceATImpl impl;

    @Bean
    public Endpoint endpoint() {
        EndpointImpl endpoint = new EndpointImpl(bus, impl);
        endpoint.publish("/Service/SecondServiceAT");
        return endpoint;
    }

    @Bean
    public Endpoint participant() {
        EndpointImpl endpoint = new EndpointImpl(bus, new ParticipantPortTypeImpl());
        endpoint.publish("/ws-t11-participant/ParticipantService");
        return endpoint;
    }
}
